<?php

namespace Drupal\commerce_avatax\EventSubscriber;

use Drupal\commerce_avatax\AvataxLib;
use Drupal\commerce_order\Adjustment;
use Drupal\Core\Config\ConfigFactoryInterface;
use Drupal\state_machine\Event\WorkflowTransitionEvent;
use Symfony\Component\EventDispatcher\EventSubscriberInterface;

class CommitTransactionSubscriber implements EventSubscriberInterface {

  /**
   * The Avatax library.
   *
   * @var \Drupal\commerce_avatax\AvataxLib
   */
  protected $avataxLib;

  /**
   * The Avatax configuration.
   *
   * @var \Drupal\Core\Config\ImmutableConfig
   */
  protected $config;

  /**
   * Constructs a new CommitTransactionSubscriber object.
   *
   * @param \Drupal\commerce_avatax\AvataxLib $avatax_lib
   *   The Avatax library.
   * @param \Drupal\Core\Config\ConfigFactoryInterface $config_factory
   *   The configuration factory.
   */
  public function __construct(AvataxLib $avatax_lib, ConfigFactoryInterface $config_factory) {
    $this->avataxLib = $avatax_lib;
    $this->config = $config_factory->get('commerce_avatax.settings');
  }

  /**
   * {@inheritdoc}
   */
  public static function getSubscribedEvents() {
    $events = [
      'commerce_order.place.post_transition' => ['commitTransaction'],
    ];
    return $events;
  }

  /**
   * Commits a transaction or the order in AvaTax.
   *
   * @param \Drupal\state_machine\Event\WorkflowTransitionEvent $event
   *   The workflow transition event.
   */
  public function commitTransaction(WorkflowTransitionEvent $event) {
    /** @var \Drupal\commerce_order\Entity\OrderInterface $order */
    $order = $event->getEntity();

    if ($this->config->get('disable_commit')) {
      return;
    }

    /** @var \Drupal\commerce_order\Adjustment[] $avatax_adjustments */
    $avatax_adjustments = array_filter($order->collectAdjustments(), function (Adjustment $adjustment) use ($order) {
      return $adjustment->getType() == 'tax'
        && strpos($adjustment->getSourceId(), 'avatax|') !== FALSE;
    });

    // If no Avatax adjustments were found, stop here.
    if (!$avatax_adjustments) {
      return;
    }
    $this->avataxLib->transactionsCreate($order, 'SalesInvoice');
  }

}
